@@ -15,8 +15,9 @@ from .py_spec import PythonSpec
 class Builtin(Discover):
     def __init__(self, options):
         super(Builtin, self).__init__(options)
-        self.python_spec = options.python
+        self.python_spec = options.python if options.python else [sys.executable]
         self.app_data = options.app_data
+        self.try_first_with = options.try_first_with
 
     @classmethod
     def add_parser_arguments(cls, parser):
@@ -25,25 +26,43 @@ class Builtin(Discover):
             "--python",
             dest="python",
             metavar="py",
-            help="target interpreter for which to create a virtual (either absolute path or identifier string)",
-            default=sys.executable,
+            type=str,
+            action="append",
+            default=[],
+            help="interpreter based on what to create environment (path/identifier) "
+            "- by default use the interpreter where the tool is installed - first found wins",
+        )
+        parser.add_argument(
+            "--try-first-with",
+            dest="try_first_with",
+            metavar="py_exe",
+            type=str,
+            action="append",
+            default=[],
+            help="try first these interpreters before starting the discovery",
         )
 
     def run(self):
-        return get_interpreter(self.python_spec, self.app_data.folder)
+        for python_spec in self.python_spec:
+            result = get_interpreter(python_spec, self.try_first_with, self.app_data, self._env)
+            if result is not None:
+                return result
+        return None
 
     def __repr__(self):
         return ensure_str(self.__unicode__())
 
     def __unicode__(self):
-        return "{} discover of python_spec={!r}".format(self.__class__.__name__, self.python_spec)
+        spec = self.python_spec[0] if len(self.python_spec) == 1 else self.python_spec
+        return "{} discover of python_spec={!r}".format(self.__class__.__name__, spec)
 
 
-def get_interpreter(key, app_data=None):
+def get_interpreter(key, try_first_with, app_data=None, env=None):
     spec = PythonSpec.from_string_spec(key)
     logging.info("find interpreter for spec %r", spec)
     proposed_paths = set()
-    for interpreter, impl_must_match in propose_interpreters(spec, app_data):
+    env = os.environ if env is None else env
+    for interpreter, impl_must_match in propose_interpreters(spec, try_first_with, app_data, env):
         key = interpreter.system_executable, impl_must_match
         if key in proposed_paths:
             continue
@@ -54,40 +73,58 @@ def get_interpreter(key, app_data=None):
         proposed_paths.add(key)
 
 
-def propose_interpreters(spec, app_data):
-    # 1. if it's an absolute path and exists, use that
-    if spec.is_abs and os.path.exists(spec.path):
-        yield PythonInfo.from_exe(spec.path, app_data), True
+def propose_interpreters(spec, try_first_with, app_data, env=None):
+    # 0. try with first
+    env = os.environ if env is None else env
+    for py_exe in try_first_with:
+        path = os.path.abspath(py_exe)
+        try:
+            os.lstat(path)  # Windows Store Python does not work with os.path.exists, but does for os.lstat
+        except OSError:
+            pass
+        else:
+            yield PythonInfo.from_exe(os.path.abspath(path), app_data, env=env), True
 
-    # 2. try with the current
-    yield PythonInfo.current_system(app_data), True
+    # 1. if it's a path and exists
+    if spec.path is not None:
+        try:
+            os.lstat(spec.path)  # Windows Store Python does not work with os.path.exists, but does for os.lstat
+        except OSError:
+            if spec.is_abs:
+                raise
+        else:
+            yield PythonInfo.from_exe(os.path.abspath(spec.path), app_data, env=env), True
+        if spec.is_abs:
+            return
+    else:
+        # 2. otherwise try with the current
+        yield PythonInfo.current_system(app_data), True
 
-    # 3. otherwise fallback to platform default logic
-    if IS_WIN:
-        from .windows import propose_interpreters
+        # 3. otherwise fallback to platform default logic
+        if IS_WIN:
+            from .windows import propose_interpreters
 
-        for interpreter in propose_interpreters(spec, app_data):
-            yield interpreter, True
-
-    paths = get_paths()
-    # find on path, the path order matters (as the candidates are less easy to control by end user)
+            for interpreter in propose_interpreters(spec, app_data, env):
+                yield interpreter, True
+    # finally just find on path, the path order matters (as the candidates are less easy to control by end user)
+    paths = get_paths(env)
     tested_exes = set()
     for pos, path in enumerate(paths):
         path = ensure_text(path)
-        logging.debug(LazyPathDump(pos, path))
+        logging.debug(LazyPathDump(pos, path, env))
         for candidate, match in possible_specs(spec):
             found = check_path(candidate, path)
             if found is not None:
                 exe = os.path.abspath(found)
                 if exe not in tested_exes:
                     tested_exes.add(exe)
-                    interpreter = PathPythonInfo.from_exe(exe, app_data, raise_on_error=False)
+                    interpreter = PathPythonInfo.from_exe(exe, app_data, raise_on_error=False, env=env)
                     if interpreter is not None:
                         yield interpreter, match
 
 
-def get_paths():
-    path = os.environ.get(str("PATH"), None)
+def get_paths(env):
+    path = env.get(str("PATH"), None)
     if path is None:
         try:
             path = os.confstr("CS_PATH")
@@ -101,16 +138,17 @@ def get_paths():
 
 
 class LazyPathDump(object):
-    def __init__(self, pos, path):
+    def __init__(self, pos, path, env):
         self.pos = pos
         self.path = path
+        self.env = env
 
     def __repr__(self):
         return ensure_str(self.__unicode__())
 
     def __unicode__(self):
         content = "discover PATH[{}]={}".format(self.pos, self.path)
-        if os.environ.get(str("_VIRTUALENV_DEBUG")):  # this is the over the board debug
+        if self.env.get(str("_VIRTUALENV_DEBUG")):  # this is the over the board debug
             content += " with =>"
             for file_name in os.listdir(self.path):
                 try:
@@ -145,4 +183,4 @@ def possible_specs(spec):
 
 
 class PathPythonInfo(PythonInfo):
-    """"""
+    """ """
